@@ -1,6 +1,6 @@
 // aac encoding functions for butt
 //
-// Copyright 2007-20016 by Daniel Noethen.
+// Copyright 2007-2018 by Daniel Noethen.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,12 +16,15 @@
 #ifndef AAC_ENCODE_H
 #define AAC_ENCODE_H
 
-#include <fdk-aac/aacenc_lib.h>
+#include "config.h"
 
+#ifdef HAVE_LIBFDK_AAC 
+ #include <fdk-aac/aacenc_lib.h>
 struct aac_enc {
 	HANDLE_AACENCODER handle;
 	AACENC_InfoStruct info;
     int aot;
+    int overwrite_aot;
     int bitrate;
     int samplerate;
     int channel;
@@ -37,6 +40,7 @@ int aac_enc_init(aac_enc *aac);
 int aac_enc_encode(aac_enc *aac, short *pcm_buf, char *enc_buf, int samples, int size);
 int aac_enc_reinit(aac_enc *aac);
 void aac_enc_close(aac_enc *aac);
+#endif
 
 #endif
 
