@@ -1,6 +1,6 @@
 // config functions for butt
 //
-// Copyright 2007-2008 by Daniel Noethen.
+// Copyright 2007-2018 by Daniel Noethen.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -97,6 +97,9 @@ int cfg_write_file(char *path)
         fprintf(cfg_fd, "song_path = \n");
 
     fprintf(cfg_fd, "song_update = %d\n", cfg.main.song_update);
+    
+    fprintf(cfg_fd, "app_update_service = %d\n", cfg.main.app_update_service);
+    fprintf(cfg_fd, "app_update = %d\n", cfg.main.app_update);
 
     fprintf(cfg_fd, "gain = %f\n", cfg.main.gain);
 
@@ -114,16 +117,18 @@ int cfg_write_file(char *path)
             "bitrate = %d\n"
             "channel = %d\n"
             "codec = %s\n"
-            "resample_mode = %d\n"
+            "aac_overwrite_aot = %d\n"
             "aac_aot = %d\n"
+            "resample_mode = %d\n"
             "buffer_ms = %d\n\n",
             cfg.audio.dev_num,
             cfg.audio.samplerate,
             cfg.audio.bitrate,
             cfg.audio.channel,
             cfg.audio.codec,
-            cfg.audio.resample_mode,
+            cfg.audio.aac_overwrite_aot,
             cfg.audio.aac_aot,
+            cfg.audio.resample_mode,
             cfg.audio.buffer_ms
            );
 
@@ -144,6 +149,22 @@ int cfg_write_file(char *path)
             cfg.rec.filename,
             cfg.rec.folder
            );
+    
+    fprintf(cfg_fd,
+            "[dsp]\n"
+            "equalizer = %d\n"
+            "gain1 = %f\n"
+            "gain2 = %f\n"
+            "gain3 = %f\n"
+            "gain4 = %f\n"
+            "gain5 = %f\n\n",
+            cfg.dsp.equalizer,
+            cfg.dsp.gain1,
+            cfg.dsp.gain2,
+            cfg.dsp.gain3,
+            cfg.dsp.gain4,
+            cfg.dsp.gain5
+            );
 
     fprintf(cfg_fd,
             "[gui]\n"
@@ -259,6 +280,7 @@ int cfg_set_values(char *path)
     cfg.audio.codec      = cfg_get_str("audio", "codec");
     cfg.audio.buffer_ms  = cfg_get_int("audio", "buffer_ms");
     cfg.audio.aac_aot    = cfg_get_int("audio", "aac_aot");
+    cfg.audio.aac_overwrite_aot = cfg_get_int("audio", "aac_overwrite_aot");
     cfg.audio.pcm_list   = snd_get_devices(&cfg.audio.dev_count);
 
     cfg.audio.resample_mode  = cfg_get_int("audio", "resample_mode");
@@ -287,9 +309,16 @@ int cfg_set_values(char *path)
     if(cfg.audio.buffer_ms == -1)
         cfg.audio.buffer_ms = 50;
 
-    if(cfg.audio.aac_aot == -1)
-        cfg.audio.aac_aot = 5; // aac+ v1
+    if(cfg.audio.aac_overwrite_aot == -1)
+        cfg.audio.aac_overwrite_aot = 0;
+    
+#ifdef HAVE_LIBFDK_AAC
+    aac_stream.overwrite_aot = cfg.audio.aac_overwrite_aot;
+    aac_rec.overwrite_aot = cfg.audio.aac_overwrite_aot;
+#endif
 
+    if(cfg.audio.aac_aot == -1)
+        cfg.audio.aac_aot = 5;
 
     if(cfg.audio.resample_mode == -1)
         cfg.audio.resample_mode = 0; //SRC_SINC_BEST_QUALITY
@@ -496,6 +525,13 @@ int cfg_set_values(char *path)
     cfg.main.song_update = cfg_get_int("main", "song_update");
     if(cfg.main.song_update == -1)
         cfg.main.song_update = 0; //song update from file is default set to off
+    
+    cfg.main.app_update = cfg_get_int("main", "app_update");
+    cfg.main.app_update_service = cfg_get_int("main", "app_update_service");
+    if(cfg.main.app_update == -1)
+        cfg.main.app_update = 0; //Default value, off
+    if(cfg.main.app_update_service == -1)
+        cfg.main.app_update_service = 0; //Default value, first one
 
 	cfg.main.connect_at_startup = cfg_get_int("main", "connect_at_startup");
 	if(cfg.main.connect_at_startup == -1)
@@ -509,7 +545,32 @@ int cfg_set_values(char *path)
     else if(cfg.main.gain < 0)
         cfg.main.gain = util_db_to_factor(-24);
 
+    // DSP
+    cfg.dsp.equalizer = cfg_get_int("dsp", "equalizer");
+    if (cfg.dsp.equalizer == -1)
+        cfg.dsp.equalizer = 0;
+    
+    cfg.dsp.gain1 = cfg_get_float("dsp", "gain1");
+    if (cfg.dsp.gain1 == -1)
+        cfg.dsp.gain1 = 0.0;
+    
+    cfg.dsp.gain2 = cfg_get_float("dsp", "gain2");
+    if (cfg.dsp.gain2 == -1)
+        cfg.dsp.gain2 = 0.0;
+    
+    cfg.dsp.gain3 = cfg_get_float("dsp", "gain3");
+    if (cfg.dsp.gain3 == -1)
+        cfg.dsp.gain3 = 0.0;
+    
+    cfg.dsp.gain4 = cfg_get_float("dsp", "gain4");
+    if (cfg.dsp.gain4 == -1)
+        cfg.dsp.gain4 = 0.0;
+    
+    cfg.dsp.gain5 = cfg_get_float("dsp", "gain5");
+    if (cfg.dsp.gain5 == -1)
+        cfg.dsp.gain5 = 0.0;
 
+    
     //read GUI stuff 
     cfg.gui.attach = cfg_get_int("gui", "attach");
     if(cfg.gui.attach == -1)
@@ -593,6 +654,7 @@ int cfg_create_default(void)
             "codec = mp3\n"
             "resample_mode = 0\n" //SRC_SINC_BEST_QUALITY
             "aac_aot = 5\n" // aac+ v1
+            "aac_overwrite_aot = 0\n"
             "buffer_ms = 50\n\n"
            );
 
@@ -608,6 +670,15 @@ int cfg_create_default(void)
             "filename = rec_%%Y%%m%%d-%%H%%M%%S.mp3\n"
             "folder = %s\n\n", def_rec_folder
            );
+    
+    fprintf(cfg_fd,
+            "[dsp]\n"
+            "equalizer = 0\n"
+            "gain1 = 0.0\n"
+            "gain2 = 0.0\n"
+            "gain3 = 0.0\n"
+            "gain4 = 0.0\n"
+            "gain5 = 0.0\n");
 
     fprintf(cfg_fd, 
             "[gui]\n"
