@@ -1,6 +1,6 @@
 // shoutcast functions for butt
 //
-// Copyright 2007-2008 by Daniel Noethen.
+// Copyright 2007-2018 by Daniel Noethen.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -99,10 +99,9 @@ int sc_connect(void)
     }
 
     error_printed = 0;
-
-    sock_send(&stream_socket, cfg.srv[cfg.selected_srv]->pwd,
-            strlen(cfg.srv[cfg.selected_srv]->pwd), SEND_TIMEOUT);
-    sock_send(&stream_socket, "\n", 1, SEND_TIMEOUT);
+    
+    snprintf(send_buf, sizeof(send_buf), "%s%s", cfg.srv[cfg.selected_srv]->pwd, "\r\n");
+    sock_send(&stream_socket, send_buf, strlen(send_buf), SEND_TIMEOUT);
     
     // Make butt compatible to proxies/load balancers. Thanks to boyska
     if(cfg.srv[cfg.selected_srv]->port == 80)
@@ -144,24 +143,31 @@ int sc_connect(void)
         strcpy(send_buf,  "audio/ogg");
 
     sock_send(&stream_socket, send_buf, strlen(send_buf), SEND_TIMEOUT);
+   
     
     sock_send(&stream_socket, "\r\n\r\n", 4, SEND_TIMEOUT);
 
-
-
-    if((ret = sock_recv(&stream_socket, recv_buf, sizeof(recv_buf)-1, RECV_TIMEOUT)) == 0)
+    if((ret = sock_recv(&stream_socket, recv_buf, sizeof(recv_buf)-1, 5*RECV_TIMEOUT)) == 0)
     {
         usleep(100*1000);
         sc_disconnect();
         return 1;
     }
+    
+    if (ret == SOCK_TIMEOUT)
+    {
+        print_info("\nconnect: connection timed out. Trying again...\n", 1);
+        usleep(100*1000);
+        sc_disconnect();
+        return 1;
+    }
 
     recv_buf[ret] = '\0';
     
 
     if( (recv_buf[0] != 'O') || (recv_buf[1] != 'K') || (ret <= 2) )
     {
-        if(strstr(recv_buf, "invalid password") != NULL)
+        if(strstr(recv_buf, "invalid password") != NULL || (strstr(recv_buf, "Invalid Password") != NULL))
         {
             print_info("\nConnect: Invalid password!\n", 1);
             sc_disconnect();
@@ -172,8 +178,6 @@ int sc_connect(void)
 
 
 
- 
-
     connected = 1;
 
     timer_init(&stream_timer, 1);       //starts the "online" timer
